@@ -21,9 +21,21 @@ plot.cLHS_result <- function(
 
   pl <- list()
 
+  ## Temporary fix for 0.9.2
+  require(ggplot2)
+
+  ## Back-compatibility snippet code for ggplot2
+  ver <- as.numeric_version(packageVersion('ggplot2'))
+
   # Objective function plot
   if ("obj" %in% modes) {
-    objective_plot <- ggplot(df_obj) + geom_line(aes(x = iter, y = obj)) + labs(x = "Iteration", y = "Objective function") + theme_bw()  + opts(title = "Evolution of the objective function")
+
+    ## Back-compatibility snippet code for ggplot2
+    if (ver >= as.numeric_version("0.9.2")) {
+      objective_plot <- ggplot(df_obj) + geom_line(aes(x = iter, y = obj)) + labs(title = "Evolution of the objective function", x = "Iteration", y = "Objective function") + theme_bw()
+    } else {
+      objective_plot <- ggplot(df_obj) + geom_line(aes(x = iter, y = obj)) + labs(x = "Iteration", y = "Objective function") + theme_bw() + opts(title = "Evolution of the objective function")
+    }
 
     pl[[length(pl) + 1]] <- objective_plot
     names(pl)[length(pl)] <- 'obj'
@@ -31,8 +43,14 @@ plot.cLHS_result <- function(
 
   # Cost function plot
   if ("cost" %in% modes) {
-    cost_plot <- ggplot(df_obj) + geom_line(aes(x = iter, y = cost)) + labs(x = "Iteration", y = "Cost function") + theme_bw()  + opts(title = "Evolution of the cost function")
 
+    ## Back-compatibility snippet code for ggplot2
+    if (ver >= as.numeric_version("0.9.2")) {
+      cost_plot <- ggplot(df_obj) + geom_line(aes(x = iter, y = cost)) + labs(title = "Evolution of the cost function", x = "Iteration", y = "Cost function") + theme_bw()
+    } else {
+      cost_plot <- ggplot(df_obj) + geom_line(aes(x = iter, y = cost)) + labs(x = "Iteration", y = "Cost function") + theme_bw()  + opts(title = "Evolution of the cost function")
+    }
+    
     pl[[length(pl) + 1]] <- cost_plot
     names(pl)[length(pl)] <- 'cost'
   }
@@ -101,11 +119,19 @@ plot.cLHS_result <- function(
       names(df_prop_table)[3] <- 'level'
  
       # Plot for factors (bar counts)
-      distrib_factor <- ggplot(df_prop_table) + 
-        geom_point(aes(x = level, y = value, colour = id)) + 
-        facet_wrap(~ variable, scales = "free") + 
-        theme_bw() + opts(title = "Discrete variables") 
-      
+      ## Back-compatibility snippet code for ggplot2
+      if (ver >= as.numeric_version("0.9.2")) {
+        distrib_factor <- ggplot(df_prop_table) + 
+          geom_point(aes(x = level, y = value, colour = id)) + 
+          facet_wrap(~ variable, scales = "free") + 
+          theme_bw() + labs(title = "Discrete variables") 
+      } else {
+        distrib_factor <- ggplot(df_prop_table) + 
+          geom_point(aes(x = level, y = value, colour = id)) + 
+          facet_wrap(~ variable, scales = "free") + 
+          theme_bw() + opts(title = "Discrete variables") 
+      }
+            
       pl[[length(pl) + 1]] <- distrib_factor + 
         scale_y_continuous(name = "Relative  Frequency", labels = percent) + scale_x_discrete(name = "Level") +
         scale_colour_discrete(name = "")
@@ -121,12 +147,70 @@ plot.cLHS_result <- function(
       df_hist_continuous <- melt(rbind(init_continuous, spl_continuous), idcolname)
       
       # Plot for continuous
-      if ('dens' %in% modes)
-        distrib_continuous <- ggplot(df_hist_continuous) + geom_density(aes_string(x = 'value', fill = idcolname), alpha = 0.5) + facet_wrap( ~ variable, scales = "free") + theme_bw()  + opts(title = "Continuous variables") + scale_fill_discrete(name = "") + scale_x_continuous(name = "Value") + scale_y_continuous(name = "Density")
-      if ('hist' %in% modes)
-        distrib_continuous <- ggplot(df_hist_continuous) + geom_histogram(aes_string(x = 'value', fill = idcolname), position = 'dodge') + facet_wrap(~ variable, scales = "free") + theme_bw()  + opts(title = "Continuous variables") + scale_fill_discrete(name = "") + scale_x_continuous(name = "Value") + scale_y_continuous(name = "Count")
-      if ('box' %in% modes)
-        distrib_continuous <- ggplot(df_hist_continuous) + geom_boxplot(aes_string(x = idcolname, y = 'value')) + facet_wrap( ~ variable, scales = "free") + theme_bw()  + opts(title = "Continuous variables") + scale_x_discrete(name = "") + scale_y_continuous(name = "Value")
+      if ('dens' %in% modes) {
+        ## Back-compatibility snippet code for ggplot2
+        if (ver >= as.numeric_version("0.9.2")) {
+          distrib_continuous <- ggplot(df_hist_continuous) + 
+            geom_density(aes_string(x = 'value', fill = idcolname), alpha = 0.5) + 
+            facet_wrap( ~ variable, scales = "free") + 
+            theme_bw()  + 
+            labs(title = "Continuous variables") + 
+            scale_fill_discrete(name = "") + 
+            scale_x_continuous(name = "Value") + 
+            scale_y_continuous(name = "Density")
+        } else {
+          distrib_continuous <- ggplot(df_hist_continuous) + 
+            geom_density(aes_string(x = 'value', fill = idcolname), alpha = 0.5) + 
+            facet_wrap( ~ variable, scales = "free") + 
+            theme_bw()  + 
+            opts(title = "Continuous variables") + 
+            scale_fill_discrete(name = "") + 
+            scale_x_continuous(name = "Value") + 
+            scale_y_continuous(name = "Density")
+        }
+      }
+      if ('hist' %in% modes) {
+        ## Back-compatibility snippet code for ggplot2
+        if (ver >= as.numeric_version("0.9.2")) {
+          distrib_continuous <- ggplot(df_hist_continuous) + 
+            geom_histogram(aes_string(x = 'value', fill = idcolname), position = 'dodge') + 
+            facet_wrap(~ variable, scales = "free") + 
+            theme_bw() + 
+            labs(title = "Continuous variables") + 
+            scale_fill_discrete(name = "") + 
+            scale_x_continuous(name = "Value") + 
+            scale_y_continuous(name = "Count")
+        } else {
+          distrib_continuous <- ggplot(df_hist_continuous) + 
+            geom_histogram(aes_string(x = 'value', fill = idcolname), position = 'dodge') + 
+            facet_wrap(~ variable, scales = "free") + 
+            theme_bw() + 
+            opts(title = "Continuous variables") + 
+            scale_fill_discrete(name = "") + 
+            scale_x_continuous(name = "Value") + 
+            scale_y_continuous(name = "Count")
+        }
+      }
+      if ('box' %in% modes) {
+        ## Back-compatibility snippet code for ggplot2
+        if (ver >= as.numeric_version("0.9.2")) {
+          distrib_continuous <- ggplot(df_hist_continuous) + 
+            geom_boxplot(aes_string(x = idcolname, y = 'value')) + 
+            facet_wrap( ~ variable, scales = "free") + 
+            theme_bw() + 
+            labs(title = "Continuous variables") + 
+            scale_x_discrete(name = "") + 
+            scale_y_continuous(name = "Value")
+        } else {
+          distrib_continuous <- ggplot(df_hist_continuous) + 
+            geom_boxplot(aes_string(x = idcolname, y = 'value')) + 
+            facet_wrap( ~ variable, scales = "free") + 
+            theme_bw() + 
+            opts(title = "Continuous variables") + 
+            scale_x_discrete(name = "") + 
+            scale_y_continuous(name = "Value")
+        }
+      }
 
       pl[[length(pl) + 1]] <- distrib_continuous 
 
